package com.fs.live.service;


import com.fs.live.domain.LiveLotteryRecord;

import java.util.List;

/**
 * 直播抽奖记录Service接口
 *
 * @author fs
 * @date 2025-07-17
 */
public interface ILiveLotteryRecordService {
    /**
     * 查询直播抽奖记录
     *
     * @param lotteryId 直播抽奖记录主键
     * @return 直播抽奖记录
     */
    LiveLotteryRecord selectLiveLotteryRecordByLotteryId(Long lotteryId);

    /**
     * 查询直播抽奖记录列表
     *
     * @param liveLotteryRecord 直播抽奖记录
     * @return 直播抽奖记录集合
     */
    List<LiveLotteryRecord> selectLiveLotteryRecordList(LiveLotteryRecord liveLotteryRecord);

    /**
     * 新增直播抽奖记录
     *
     * @param liveLotteryRecord 直播抽奖记录
     * @return 结果
     */
    int insertLiveLotteryRecord(LiveLotteryRecord liveLotteryRecord);

    /**
     * 修改直播抽奖记录
     *
     * @param liveLotteryRecord 直播抽奖记录
     * @return 结果
     */
    int updateLiveLotteryRecord(LiveLotteryRecord liveLotteryRecord);

    /**
     * 批量删除直播抽奖记录
     *
     * @param lotteryIds 需要删除的直播抽奖记录主键集合
     * @return 结果
     */
    int deleteLiveLotteryRecordByLotteryIds(Long[] lotteryIds);

    /**
     * 删除直播抽奖记录信息
     *
     * @param lotteryId 直播抽奖记录主键
     * @return 结果
     */
    int deleteLiveLotteryRecordByLotteryId(Long lotteryId);
}
